Changes
=======

0.2 (2016-04-26)
----------------

* more training examples;
* fixed Scrapy < 1.1 support;
* fixed a bug in text-before and text-after features.

0.1 (2016-03-15)
----------------

Initial release
